==> worlds_yugiohddm-0.0.0.tar.gz: worlds_yugiohddm-0.0.0/src/worlds/yugiohddm/docs/en_Yu-Gi-Oh! Dungeon Dice Monsters.md <==

# Yu-Gi-Oh! Dungeon Dice Monsters

## What does randomization do to this game?

You will play the game in Free Duel mode or Tournament mode, depending on your chosen Progression method in the YAML.
In Tournament mode you will start with the first division of tournaments available, beating a tournament for the first time
will unlock a check. Eventually Division 2 (Reverse) will be found and you will gain access to those tournaments, as well as
Division 3 (Dark). Once you have beaten every tournament in Division 3 except The Last Judgment, it will unlock.
In Free Duel mode you will start with the defined number of duelists unlocked (set in your YAML),
defeating each duelist for the first time will unlock a check. Over time you will unlock more duelists as those checks are found by
by players in the multiworld. Once all duelists other than Yami Yugi are unlocked, he will be unlocked.

## What is the goal of Yu-Gi-Oh! Dungeon Dice Monsters when randomized?

In Tournament mode, complete The Last Judgment.
In Free Duel mode, Defeat Yami Yugi.

## What items and locations get shuffled?

In Tournament mode your access to the other tournament divisions is shuffled.
In Free Duel mode your access to more duelists is shuffled.
Filler checks in both modes are Dice that get added to your collection.

## Which items can be in another player's world?

In Tournament mode your Reverse and Dark Division items (allow you to play in those Tournament Divisions).
In Free Duel mode your Duelist Unlock items (allowing you to play against them in Free Duel).
In both modes in a case where filler checks are created, Dice that can be added to your collection.

## What does another world's item look like in Yu-Gi-Oh! Forbidden Memories

Your item acquisitions take the form of having defeated duelists or tournaments. As such,
you'll have to check the BizHawk Client to know the actual items that were unlocked from those locations.

## When the player receives an item, what happens?

Currently, the items are silently added to the player's inventory, which can be seen in the dice pool, Free Duel menu or Tournament menu.

## Can I play Tournaments in Free Duel mode and Free Duels in Tournament mode?

Playing in Tournaments when your progression mode is Free Duel will break logic.
In Tournament mode you are free to play against as many duelists in Free Duel as you like,
you may also replay tournaments to increase Grandpa's Shop progress and earn more money.

==> worlds_yugiohddm-0.3.0.tar.gz: worlds_yugiohddm-0.3.0/src/worlds/yugiohddm/docs/en_Yu-Gi-Oh! Dungeon Dice Monsters.md <==

# Yu-Gi-Oh! Dungeon Dice Monsters

## What does randomization do to this game?

You will play the game in Free Duel mode or Tournament mode, depending on your chosen Progression method in the YAML.
In Tournament mode you will start with the first division of tournaments available, beating a tournament for the first time
will unlock checks. Eventually Division 2 (Reverse) will be found and you will gain access to those tournaments, as well as
Division 3 (Dark). Once you have beaten every tournament in Division 3 except The Last Judgment, it will unlock.

In Free Duel mode you will start with the defined number of duelists unlocked (set in your YAML),
defeating each duelist for the first time will unlock checks. Over time you will unlock more duelists as those checks are found by
by players in the multiworld. Once you've beaten enough duelists, Yami Yugi will be unlocked.

## What is the goal of Yu-Gi-Oh! Dungeon Dice Monsters when randomized?

In Tournament mode, complete The Last Judgment.
In Free Duel mode, Defeat Yami Yugi.

## What items and locations get shuffled?

In Tournament mode your access to the other tournament divisions is shuffled.
In Free Duel mode your access to more duelists is shuffled.
Filler checks can either be random dice or shop progression and money.
If bonus item mode is set to Shop, you can collect dice from winning
duels and by buying them from Grandpa's Shop to send checks.

## Which items can be in another player's world?

In Tournament mode your Reverse and Dark Division items (allow you to play in those Tournament Divisions).
In Free Duel mode your Duelist Unlock items (allowing you to play against them in Free Duel).
In either mode based on your bonus item mode, either dice or shop progression and money items.

## What does another world's item look like in Yu-Gi-Oh! Forbidden Memories

Your item acquisitions take the form of having defeated duelists or tournaments, or collecting dice. As such,
you'll have to check the BizHawk Client to know the actual items that were unlocked from those locations.

## When the player receives an item, what happens?

Currently, the items are silently added to the player's inventory, which can be seen in the dice pool, Free Duel menu, Tournament menu, or Grandpa's Shop.

## Can I play Tournaments in Free Duel mode and Free Duels in Tournament mode?

Playing in Tournaments when your progression mode is Free Duel will break logic.
In Tournament mode you are free to play against as many duelists in Free Duel as you like.
